# ReinstatementSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**site_reference_number** | **str** |  | 
**work_reference_number** | **str** |  | 
**reinstatement_reference_number** | **str** |  | 
**promoter_organisation** | **str** |  | 
**highway_authority** | **str** |  | 
**street_name** | **str** |  | 
**town** | **str** |  | [optional] 
**area_name** | **str** |  | [optional] 
**location_description** | **str** |  | 
**registration_date** | **datetime** |  | 
**reinstatement_date** | **datetime** |  | [optional] 
**reinstatement_type** | [**ReinstatementTypeResponse**](ReinstatementTypeResponse.md) |  | 
**reinstatement_type_string** | **str** |  | 
**reinstatement_status** | [**ReinstatementStatusResponse**](ReinstatementStatusResponse.md) |  | 
**reinstatement_status_string** | **str** |  | 
**end_date** | **datetime** |  | [optional] 
**is_active_reinstatement** | **bool** |  | 
**is_subsumed** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

